@@ -905,6 +905,42 @@ public abstract class Page implements Serializable {
 		return buf.toString();
 	}
 
+	/**
+	 * ロード時に実行する JavaScript の登録。
+	 * このページがブラウザにロードされた時に実行したいスクリプトの指定。<br>
+	 * このメソッドの呼び出しの度にスクリプトが追加されます。
+	 * また、このページがブラウザへ出力されると、この登録内容がクリアされます。
+	 * @param script 実行スクリプト。各Stringには改行が付けられます。
+	 */
+	public void addOnLoadScript( String ... script ) {
+		paraselene.ajax.data.JavaScript	js = null;
+		if ( onload.getHTMLPartCount() == 0 ) {
+			js = new paraselene.ajax.data.JavaScript( script );
+			onload.addHTMLPart( js );
+			return;
+		}
+		js = (paraselene.ajax.data.JavaScript)onload.getHTMLPart( 0 );
+		js.append( script );
+	}
+
+	/**
+	 * ロード時に実行する JavaScript を返します。
+	 * @return JavaScript。
+	 */
+	public String getOnLoadScript() {
+		return onload.getHTMLPart( 0 ).toString();
+	}
+
+	/**
+	 * ロード時に実行する JavaScript をクリアします。
+	 * Paraselene 自身も JavaScript を登録しています。
+	 * 不用意にクリアしないで下さい。
+	 */
+	public void resetOnLoadScript() {
+		onload.removeHTMLPart();
+		onload.addHTMLPart( new paraselene.ajax.data.JavaScript() );
+	}
+
 	/**
 	 * 出力。
 	 * @param w ライター。
@@ -922,6 +958,7 @@ public abstract class Page implements Serializable {
 		if ( contents != null ) {
 			contents.write( w, HTMLPart.StringMode.BODY );
 		}
+		resetOnLoadScript();
 	}
 
 	/**
@@ -1083,7 +1120,7 @@ public abstract class Page implements Serializable {
 					new Attribute( "id", AJAX_ADD_ID )
 				);
 				body.removeHTMLPart();
-				body.addHTMLPart( div[0], div[1] /*, Tag.makeScript(
+				body.addHTMLPart( div[0], div[1], onload /*, Tag.makeScript(
 					"paraselene_add_event(paraselene_get_id('paraseleneDragonsTail'),'load',setTimeout(paraselene_form_comp,2000);"
 				) */ );
 			}
@@ -1100,6 +1137,7 @@ public abstract class Page implements Serializable {
 	private RequestParameter	now_req;
 	private RequestParameter.Mobile			access_mobile;
 	private RequestParameter.SearchEngine	access_se;
+	private Tag	onload = Tag.makeScript();
 	private boolean safari_f = false;
 
 	/**
@@ -1108,7 +1146,6 @@ public abstract class Page implements Serializable {
 	 * <li>{@link #getAjaxSupport()}で、AjaxSupport.NO 以外を返した場合。
 	 * <li>携帯アクセスではない。
 	 * <li>検索エンジンのクローラーではない。
-	 * <li>Safari からのアクセスではない。
 	 * </ul>
 	 * @return true:利用可能、false:利用不可。
 	 */
@@ -1122,10 +1159,12 @@ public abstract class Page implements Serializable {
 		if ( req != null ) {
 			access_mobile = req.judgeMobile();
 			access_se = req.judgeSearchEngine();
+/***
 			String[]	ua = req.getHeader( "User-Agent" );
 			if ( ua != null ) {
 				safari_f = ( ua[0].indexOf( "Chrome" ) == -1 && ua[0].indexOf( "Safari" ) >= 0 );
 			}
+***/
 		}
 	}
 
