@@ -264,7 +264,9 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 		if ( q == null ) {
 			return new QueryItem[0];
 		}
-		String[]	str = q.split( "&" );
+		String[]	pre = q.split( "\\?" );
+		if ( pre.length < 2 )	return new QueryItem[0];
+		String[]	str = pre[1].split( "&" );
 		ArrayList<QueryItem>	list = new ArrayList<QueryItem>();
 		for ( int i = 0; i < str.length; i++ ) {
 			String[]	part = str[i].split( "=" );
