@@ -17,7 +17,7 @@ public class PostBack implements Serializable {
 	public TagData	tag = null;
 	public Exec		exec = null;
 
-	protected PostBack(){}
+	public PostBack(){}
 
 	public PostBack( String l ) {
 		location = l;
