@@ -60,6 +60,7 @@ public class History implements Serializable {
 	private boolean addPopup( Page page ) {
 		if ( page.getPopupType() == null )	return false;
 		synchronized( popup ) {
+			removePopup( page );
 			popup.add( page );
 		}
 		return true;
@@ -76,6 +77,7 @@ public class History implements Serializable {
 				}
 			}
 		}
+		Option.trace( "donot remove, not found %s", key );
 	}
 
 	private void clearPopup() {
