@@ -216,10 +216,10 @@ public abstract class PageFactory extends Thread {
 		return uri;
 	}
 
+
 	AliasData getPage( String uri ) {
 		if ( !Supervisor.isMyHost( uri ) )	return null;
 		AliasData	alias_data = new AliasData();
-		uri = parseAlias( uri, alias_data );
 		String[]	path = uri.split( "#" );
 		if ( path.length == 0 )	path = new String[] { uri };
 		path = path[0].split( "\\?" );
@@ -229,6 +229,8 @@ public abstract class PageFactory extends Thread {
 		for ( int i = 0; i < path.length; i++ ) {
 			if ( path[i].length() < 4 )	continue;
 			if ( !TransactionSequencer.EXTENSION.equals( path[i].substring( path[i].length() - 3 ) ) )	continue;
+			path[i] = parseAlias( path[i], alias_data );
+			Option.trace( "alias URI = %s", uri );
 			String	hit = null;
 			for ( int j = 0; j < list_cnt; j++ ) {
 				String	name = alias_list.get( j );
@@ -248,6 +250,7 @@ public abstract class PageFactory extends Thread {
 			}
 			if ( hit == null )	continue;
 			Integer	id = alias.get( hit );
+			Option.trace( "alias id = %s", id );
 			if ( id != null ) {
 				alias_data.page = getPage( id.intValue() );
 				return alias_data;
