@@ -113,6 +113,14 @@ public class Version {
 	 * @return リソース。取得に失敗すると null を返します。
 	 */
 	public static InputStream getResource( String name ) {
+		String[]	test = name.split( "\\\\" );
+		StringBuilder	buf = new StringBuilder( test[0] );
+		for ( int i = 1; i < test.length; i++ ) {
+			buf = buf.append( "/" );
+			buf = buf.append( test[i] );
+		}
+		name = buf.toString();
+
 		ClassLoader	ld = Version.class.getClassLoader();
 		if ( ld != null ) {
 			InputStream	is = ld.getResourceAsStream( name );
