@@ -51,7 +51,7 @@ public class JsTool {
 			new OutputStreamWriter(
 			new FileOutputStream( new_file ) ) );
 		SourceHead.init( new File( "../template/head.txt" ) );
-		bw.write( SourceHead.getHead() );
+		bw.write( SourceHead.getHead( new_file ) );
 		bw.write( pk.toString() );
 		bw.write( "public class " );
 		bw.write( name[0] );
@@ -75,6 +75,7 @@ public class JsTool {
 					bw.write( ch[i] );
 				}
 			}
+			bw.write( "\\n" );
 		}
 		bw.write( "\";" );
 		bw.write( "}\n" );
